<?php
/**
 * Get message list.
 *
 * @param string $type      the message type
 * @param int    $status    the message status
 * @param object $pager
 * @access public
 * @return void
 */
public function getList($type, $status, $pager = null)
{
    $this->app->loadLang('order');

    $messages = $this->dao->select('*')->from(TABLE_MESSAGE)
        ->where('type')->eq($type)
        ->andWhere('status')->eq($status)
        ->beginIf(RUN_MODE == 'front')->andWhere('public')->eq(1)->fi()
        ->orderBy('id_desc')
        ->page($pager)
        ->fetchAll('id');

    /* Get object titles and id. */
    $articles   = array();
    $products   = array();
    $books      = array();
    $messageIDs = array();
    $comments   = array();
    $orders     = array();

    foreach($messages as $message)
    {
        if('article' == $message->objectType) $articles[]   = $message->objectID;
        if('product' == $message->objectType) $products[]   = $message->objectID;
        if('book'    == $message->objectType) $books[]      = $message->objectID;
        if('message' == $message->objectType) $messageIDs[] = $message->objectID;
        if('comment' == $message->objectType) $comments[]   = $message->objectID;

        if('order' == $message->objectType) $orders[$message->objectID] = $message->objectID;
    }

    $articleTitles = $this->dao->select('id, title')->from(TABLE_ARTICLE)->where('id')->in($articles)->fetchPairs('id', 'title');
    $productTitles = $this->dao->select('id, name')->from(TABLE_PRODUCT)->where('id')->in($products)->fetchPairs('id', 'name');
    $bookTitles    = $this->dao->select('id, title')->from(TABLE_BOOK)->where('id')->in($books)->fetchPairs('id', 'title');
    $messageTitles = $this->dao->select('id, `from`')->from(TABLE_MESSAGE)->where('id')->in($messageIDs)->fetchPairs('id', 'from');
    $commentTitles = $this->dao->select('id, `from`')->from(TABLE_MESSAGE)->where('id')->in($comments)->fetchPairs('id', 'from');

    foreach($messages as $message)
    {
        if($message->objectType == 'article') $message->objectTitle = isset($articleTitles[$message->objectID]) ? $articleTitles[$message->objectID] : '';
        if($message->objectType == 'product') $message->objectTitle = isset($productTitles[$message->objectID]) ? $productTitles[$message->objectID] : '';
        if($message->objectType == 'book')    $message->objectTitle = isset($bookTitles[$message->objectID]) ? $bookTitles[$message->objectID] : '';
        if($message->objectType == 'message') $message->objectTitle = isset($messageTitles[$message->objectID]) ? $messageTitles[$message->objectID] : '';
        if($message->objectType == 'comment') $message->objectTitle = isset($commentTitles[$message->objectID]) ? $commentTitles[$message->objectID] : '';
        if($message->objectType == 'order')   $message->objectTitle = isset($orders[$message->objectID]) ? $this->lang->order->common . $orders[$message->objectID] : '';
    }

    foreach($messages as $message)
    {
        if($message->type != 'message' or ($message->type == 'message' and $message->objectType == 'order')) $message->objectViewURL = $this->getObjectLink($message);
    }

    return $messages;
}

/**
 * Get original message.
 *
 * @param  int    $messageID
 * @access public
 * @return bool | object
 */
public function getOriginal($messageID)
{
    $message = $this->dao->select('*')->from(TABLE_MESSAGE)->where('id')->eq($messageID)->fetch();
    if(strpos('message,reply,comment', $message->objectType) === false or $message->objectID == 0) return false;

    $original = $this->dao->select('*')->from(TABLE_MESSAGE)->where('id')->eq($message->objectID)->fetch();
    if($original->objectType == 'article') $original->objectTitle = $this->dao->select('title')->from(TABLE_ARTICLE)->where('id')->eq($original->objectID)->fetch('title');
    if($original->objectType == 'product') $original->objectTitle = $this->dao->select('name')->from(TABLE_PRODUCT)->where('id')->eq($original->objectID)->fetch('name');
    if($original->objectType == 'book')    $original->objectTitle = $this->dao->select('title')->from(TABLE_BOOK)->where('id')->eq($original->objectID)->fetch('title');
    if($original->objectType == 'message' or $original->objectType == 'comment') $original->objectTitle = $original->from;
    if($original->objectType == 'order')
    {
        $this->app->loadLang('order');
        $original->objectTitle = $this->lang->order->common . $original->objectID;
    }
    $original->objectViewURL = ($original->type != 'message' or ($original->type == 'message' and $original->objectType == 'order')) ? $this->getObjectLink($original) : '';
    return $original;
}

/**
 * Get the link of the object of one message.
 *
 * @param string $message
 * @access public
 * @return sting
 */
public function getObjectLink($message)
{
    if(empty($message)) return '';
    $link = '';
    if($message->objectType == 'article')
    {
        $link = $this->loadModel('article')->createPreviewLink($message->objectID);
    }
    elseif($message->objectType == 'product')
    {
        $link = commonModel::createFrontLink('product', 'view', "prodcutID=$message->objectID");
    }
    elseif($message->objectType == 'book')
    {
        $node = $this->loadModel('book')->getNodeByID($message->objectID);
        $link = commonModel::createFrontLink('book', 'read', "articleID=$message->objectID", "book={$node->book->alias}&node={$node->alias}");
    }
    elseif($message->objectType == 'order')
    {
        $link = helper::createLink('order', 'view', "orderID=$message->objectID");
    }
    elseif($message->objectType == 'message')
    {
        $link = commonModel::createFrontLink('message', 'index') . "#comment{$message->objectID}";
    }
    elseif($message->objectType == 'comment')
    {
        $object = $this->getByID($message->objectID);
        $link   = $this->getObjectLink($object);
    }

    return $link;
}
